FlutSimClient class

Constructors

FlutSimClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

injectScript(String body, int port) String
Generates the single unified JS script to inject into the index.html. We pass the port dynamically so it always connects correctly.