UnifiedWebSocketServer class
One server to rule them all: handles hot reload, auto reload, error overlays, and instant updating.
Constructors
Properties
Methods
-
clearError(
) → void - Sends a signal that the error has been cleared (e.g. successful compile).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendError(
String errorMessage) → void - Sends an error object to render an overlay on the device.
-
sendInstantUIUpdate(
List< Map< changes) → voidString, dynamic> > - Send an instant UI update payload
-
start(
{int? preferPort}) → Future< void> -
stop(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
triggerAutoReload(
) → void - Sends a brutal full page refresh signal.
-
triggerHotReload(
) → void - Sends the instant hot reload signal to the flutter engine via JS.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited